==> haskell-parsec-3.1.11-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsec
version: 3.1.11
id: parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
key: parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/aslatter/parsec
synopsis: Monadic parser combinators
description:
    Parsec is designed from scratch as an industrial-strength parser
    library.  It is simple, safe, well documented (on the package
    homepage), has extensive libraries, good error messages,
    and is fast.  It is defined as a monad transformer that can be
    stacked on arbitrary monads, and it is also parametric in the
    input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
exposed: True
indefinite: False
exposed-modules:
    Text.Parsec Text.Parsec.ByteString Text.Parsec.ByteString.Lazy
    Text.Parsec.Char Text.Parsec.Combinator Text.Parsec.Error
    Text.Parsec.Expr Text.Parsec.Language Text.Parsec.Perm
    Text.Parsec.Pos Text.Parsec.Prim Text.Parsec.String
    Text.Parsec.Text Text.Parsec.Text.Lazy Text.Parsec.Token
    Text.ParserCombinators.Parsec Text.ParserCombinators.Parsec.Char
    Text.ParserCombinators.Parsec.Combinator
    Text.ParserCombinators.Parsec.Error
    Text.ParserCombinators.Parsec.Expr
    Text.ParserCombinators.Parsec.Language
    Text.ParserCombinators.Parsec.Perm
    Text.ParserCombinators.Parsec.Pos
    Text.ParserCombinators.Parsec.Prim
    Text.ParserCombinators.Parsec.Token
abi: 893424ff0bd1ccfdf429c25df7ce2aa4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsec-3.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsec-3.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsec-3.1.11
hs-libraries: HSparsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH bytestring-0.10.8.2
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
haddock-interfaces: /usr/share/doc/haskell-parsec/html/parsec.haddock
haddock-html: /usr/share/doc/haskell-parsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsec-3.1.11-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-parsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsec
version: 3.1.11
id: parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
key: parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/aslatter/parsec
synopsis: Monadic parser combinators
description:
    Parsec is designed from scratch as an industrial-strength parser
    library.  It is simple, safe, well documented (on the package
    homepage), has extensive libraries, good error messages,
    and is fast.  It is defined as a monad transformer that can be
    stacked on arbitrary monads, and it is also parametric in the
    input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
exposed: True
indefinite: False
exposed-modules:
    Text.Parsec Text.Parsec.ByteString Text.Parsec.ByteString.Lazy
    Text.Parsec.Char Text.Parsec.Combinator Text.Parsec.Error
    Text.Parsec.Expr Text.Parsec.Language Text.Parsec.Perm
    Text.Parsec.Pos Text.Parsec.Prim Text.Parsec.String
    Text.Parsec.Text Text.Parsec.Text.Lazy Text.Parsec.Token
    Text.ParserCombinators.Parsec Text.ParserCombinators.Parsec.Char
    Text.ParserCombinators.Parsec.Combinator
    Text.ParserCombinators.Parsec.Error
    Text.ParserCombinators.Parsec.Expr
    Text.ParserCombinators.Parsec.Language
    Text.ParserCombinators.Parsec.Perm
    Text.ParserCombinators.Parsec.Pos
    Text.ParserCombinators.Parsec.Prim
    Text.ParserCombinators.Parsec.Token
abi: 5b8a6db8c81629fde3a12212030372e3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/parsec-3.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/parsec-3.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/parsec-3.1.11
hs-libraries: HSparsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-parsec/html/parsec.haddock
haddock-html: /usr/share/doc/haskell-parsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
